==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appflow/kotlin/inputs/ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsZendeskOauthRequestArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appflow.kotlin.inputs

import com.pulumi.aws.appflow.inputs.ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsZendeskOauthRequestArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property authCode The code provided by the connector when it has been authenticated via the connected app.
 * @property redirectUri The URL to which the authentication server redirects the browser after authorization has been granted.
 */
public data class
ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsZendeskOauthRequestArgs(
    public val authCode: Output<String>? = null,
    public val redirectUri: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.appflow.inputs.ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsZendeskOauthRequestArgs> {
    override fun toJava():
        com.pulumi.aws.appflow.inputs.ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsZendeskOauthRequestArgs =
        com.pulumi.aws.appflow.inputs.ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsZendeskOauthRequestArgs.builder()
            .authCode(authCode?.applyValue({ args0 -> args0 }))
            .redirectUri(redirectUri?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsZendeskOauthRequestArgs].
 */
@PulumiTagMarker
public class
ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsZendeskOauthRequestArgsBuilder
internal constructor() {
    private var authCode: Output<String>? = null

    private var redirectUri: Output<String>? = null

    /**
     * @param value The code provided by the connector when it has been authenticated via the connected app.
     */
    @JvmName("qlnvxcwxwvhcjjbj")
    public suspend fun authCode(`value`: Output<String>) {
        this.authCode = value
    }

    /**
     * @param value The URL to which the authentication server redirects the browser after authorization has been granted.
     */
    @JvmName("wugnnshbbcdhtlrf")
    public suspend fun redirectUri(`value`: Output<String>) {
        this.redirectUri = value
    }

    /**
     * @param value The code provided by the connector when it has been authenticated via the connected app.
     */
    @JvmName("svulldjblwngoowe")
    public suspend fun authCode(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.authCode = mapped
    }

    /**
     * @param value The URL to which the authentication server redirects the browser after authorization has been granted.
     */
    @JvmName("icwghvfsnpjwukvu")
    public suspend fun redirectUri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.redirectUri = mapped
    }

    internal fun build():
        ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsZendeskOauthRequestArgs =
        ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsZendeskOauthRequestArgs(
            authCode = authCode,
            redirectUri = redirectUri,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appflow/kotlin/inputs/ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsZendeskOauthRequestArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appflow.kotlin.inputs

import com.pulumi.aws.appflow.inputs.ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsZendeskOauthRequestArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property authCode The code provided by the connector when it has been authenticated via the connected app.
 * @property redirectUri The URL to which the authentication server redirects the browser after authorization has been granted.
 */
public data class
ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsZendeskOauthRequestArgs(
    public val authCode: Output<String>? = null,
    public val redirectUri: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.appflow.inputs.ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsZendeskOauthRequestArgs> {
    override fun toJava(): com.pulumi.aws.appflow.inputs.ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsZendeskOauthRequestArgs =
        com.pulumi.aws.appflow.inputs.ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsZendeskOauthRequestArgs.builder()
            .authCode(authCode?.applyValue({ args0 -> args0 }))
            .redirectUri(redirectUri?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsZendeskOauthRequestArgs].
 */
@PulumiTagMarker
public class
ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsZendeskOauthRequestArgsBuilder
internal constructor() {
    private var authCode: Output<String>? = null

    private var redirectUri: Output<String>? = null

    /**
     * @param value The code provided by the connector when it has been authenticated via the connected app.
     */
    @JvmName("uuurhupahfijnfxf")
    public suspend fun authCode(`value`: Output<String>) {
        this.authCode = value
    }

    /**
     * @param value The URL to which the authentication server redirects the browser after authorization has been granted.
     */
    @JvmName("ljelhjmjmesucvqh")
    public suspend fun redirectUri(`value`: Output<String>) {
        this.redirectUri = value
    }

    /**
     * @param value The code provided by the connector when it has been authenticated via the connected app.
     */
    @JvmName("rscaavskeslrjsms")
    public suspend fun authCode(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.authCode = mapped
    }

    /**
     * @param value The URL to which the authentication server redirects the browser after authorization has been granted.
     */
    @JvmName("yyeeoeiabjwrastd")
    public suspend fun redirectUri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.redirectUri = mapped
    }

    internal fun build(): ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsZendeskOauthRequestArgs =
        ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsZendeskOauthRequestArgs(
            authCode = authCode,
            redirectUri = redirectUri,
        )
}
